unit Cor;

//Translated from cor.h and corhdr.h

interface

uses
  ActiveX, Windows;

const
  //**** Common Language Runtime Profiling Services errors
  // Function not yet compiled.
  CORPROF_E_FUNCTION_NOT_COMPILED = $80131350;
  // The ID is not fully loaded/defined yet.
  CORPROF_E_DATAINCOMPLETE        = $80131351;
  // The Module is not configured for updateable methods.
  CORPROF_E_NOT_REJITABLE_METHODS = $80131352;
  // The Method could not be updated for re-jit.
  CORPROF_E_CANNOT_UPDATE_METHOD  = $80131353;
  // The Method has no associated IL
  CORPROF_E_FUNCTION_NOT_IL       = $80131354;
  // The thread has never run managed code before
  CORPROF_E_NOT_MANAGED_THREAD    = $80131355;
  // The function may only be called during profiler init
  CORPROF_E_CALL_ONLY_FROM_INIT   = $80131356;
  // Inprocess debugging must be enabled during init
  // Also returned when BeginInprocDebugging not called
  // before using the inprocess debugging services
  CORPROF_E_INPROC_NOT_ENABLED    = $80131357;
  // Can't get a JIT map becuase they are not enabled
  CORPROF_E_JITMAPS_NOT_ENABLED   = $80131358;
  // If a profiler tries to call BeginInprocDebugging more than
  // once, it will get this error.
  CORPROF_E_INPROC_ALREADY_BEGUN  = $80131359;
  // States that inprocess debugging not allowed at this point
  // (for example during GC callbacks or RuntimeSuspention callbacks
  CORPROF_E_INPROC_NOT_AVAILABLE  = $8013135A;
  // This is a general error used to indicated that the information
  CORPROF_E_NOT_YET_AVAILABLE     = $8013135B;

type
  // Opaque type for an enumeration handle.
  HCORENUM = THandle;
  COR_SIGNATURE = Byte;
  PCCOR_SIGNATURE = ^COR_SIGNATURE;
  PPCCOR_SIGNATURE = ^PCCOR_SIGNATURE;

  // struct used to retrieve field offset
  // used by GetClassLayout and SetClassLayout
  COR_FIELD_OFFSET = packed record
    ridOfField: ULONG;
    ulOffset: ULONG;
  end;
  PCOR_FIELD_OFFSET = ^COR_FIELD_OFFSET;
  PCCOR_FIELD_OFFSET = ^COR_FIELD_OFFSET;

  // Open bits.
type
  CorOpenFlags = TOleEnum;
const
  ofRead       =  $00000000;     // Open scope for read
  ofWrite      =  $00000001;     // Open scope for write.
  ofCopyMemory =  $00000002;     // Open scope with memory. Ask metadata to maintain its own copy of memory.
  ofCacheImage =  $00000004;     // EE maps but does not do relocations or verify image
  ofNoTypeLib  =  $00000080;     // Don't OpenScope on a typelib.

type
  IMetaDataImport = interface(IUnknown)
    ['{7DAC8207-D3AE-4c75-9B67-92801A497D44}']
    procedure CloseEnum(hEnum: HCORENUM); stdcall;
    procedure CountEnum(hEnum: HCORENUM; var pulCount: ULONG); safecall;
    procedure ResetEnum(hEnum: HCORENUM; ulPos: ULONG); safecall;
    procedure EnumTypeDefs(var phEnum: HCORENUM; rTypeDefs: PULONG;
      cMax: ULONG; var pcTypeDefs: ULONG); safecall;
    procedure EnumInterfaceImpls(var phEnum: HCORENUM; td: ULONG;
      rImpls, cMax: ULONG; var pcImpls: ULONG); safecall;
    procedure EnumTypeRefs(var phEnum: HCORENUM; rTypeRefs: PULONG;
      cMax: ULONG; var pcTypeRefs: ULONG); safecall;
    procedure FindTypeDefByName(szTypeDef: PWideChar;
      tkEnclosingClass: ULONG; out ptd: ULONG); safecall;
    procedure GetScopeProps(szName: PWideChar; cchName: ULONG;
      out pchName: ULONG; pmvid: PGuid); safecall;
    procedure GetModuleFromScope(out pmd: ULONG); safecall;
    procedure GetTypeDefProps(td: ULONG; szTypeDef: PWideChar;
      cchTypeDef: ULONG; pchTypeDef: PULONG; pdwTypeDefFlags: PDWORD;
      ptkExtends: PULONG); safecall;
    procedure GetInterfaceImplProps(iiImpl: ULONG;
      out pClass: ULONG; out ptkIface: ULONG); safecall;
    procedure GetTypeRefProps(tr: ULONG; out ptkResolutionScope: ULONG;
      szName: PWideChar; cchName: ULONG; out pchName: ULONG); safecall;
    procedure ResolveTypeRef(tr: ULONG; riid: TGuid;
      var ppIScope: IUnknown; var ptd: ULONG); safecall;
    procedure EnumMembers(var phEnum: HCORENUM; cl: ULONG;
      rMembers: PULONG; cMax: ULONG;
      out pcTokens: ULONG); safecall;
    procedure EnumMembersWithName(var phEnum: HCORENUM; cl: ULONG;
      szName: PWideChar; rMembers: PULONG; cMax: ULONG;
      out pcTokens: ULONG); safecall;
    procedure EnumMethods(var phEnum: HCORENUM; cl: ULONG;
      rMethods: PULONG; cMax: ULONG; out pcTokens: ULONG); safecall;
    procedure EnumMethodsWithName(var phEnum: HCORENUM; cl: ULONG;
      szName: PWideChar; rMethods: PULONG; cMax: LongWord;
      out pcTokens: ULONG); safecall;
    procedure EnumFields(var phEnum: HCORENUM; cl: ULONG;
      rFields: PULONG; cMax: ULONG; out pcTokens: ULONG); safecall;
    procedure EnumFieldsWithName(var phEnum: HCORENUM; cl: ULONG;
      szName: PWideChar; rFields: PULONG; cMax: LongWord;
      out pcTokens: ULONG); safecall;
    procedure EnumParams(var phEnum: HCORENUM; mb: ULONG;
      rParams: PULONG; cMax: ULONG;
      out pcTokens: ULONG); safecall;
    procedure EnumMemberRefs(var phEnum: HCORENUM; tkParent: ULONG;
      rMemberRefs: PULONG; cMax: ULONG;
      out pcTokens: ULONG); safecall;
    procedure EnumMethodImpls(var phEnum: HCORENUM; td: ULONG;
      rMethodBody: PULONG; rMethodDecl: PULONG;
      cMax: ULONG; out pcTokens: ULONG); safecall;
    procedure EnumPermissionSets(var phEnum: HCORENUM; tk: ULONG;
      dwActions: ULONG; rPermission: PULONG;
      cMax: ULONG; out pcTokens: ULONG); safecall;
    procedure FindMember(td: ULONG; szName: PWideChar;
      pvSigBlob: PCCOR_SIGNATURE; cbSigBlob: ULONG;
      out pmb: ULONG); safecall;
    procedure FindMethod(td: ULONG; szName: PWideChar;
      pvSigBlob: PCCOR_SIGNATURE; cbSigBlob: ULONG;
      out pmb: ULONG); safecall;
    procedure FindField(td: ULONG; szName: PWideChar;
      pvSigBlob: PCCOR_SIGNATURE; cbSigBlob: ULONG;
      out pmb: ULONG); safecall;
    procedure FindMemberRef(td: ULONG; szName: PWideChar;
      pvSigBlob: PCCOR_SIGNATURE; cbSigBlob: ULONG;
      out pmr: ULONG); safecall;
    procedure GetMethodProps(mb: ULONG; pClass: PULONG;
      szMethod: PWideChar; cchMethod: ULONG; pchMethod: PULONG;
      pdwAttr: PDWORD; ppvSigBlob: PPCCOR_SIGNATURE;
      pcbSigBlob: PULONG; pulCodeRVA: PULONG;
      pdwImplFlags: PDWORD); safecall;
    procedure GetMemberRefProps(mr: ULONG; out ptk: ULONG;
      szMember: PWideChar; cchMember: ULONG; pchMember: PULONG;
      ppvSigBlob: PPCCOR_SIGNATURE; pbSig: PULONG); safecall;
    procedure EnumProperties(var phEnum: HCORENUM; td: ULONG;
      rProperties: PULONG; cMax: ULONG;
      out pcProperties: ULONG); safecall;
    procedure EnumEvents(var phEnum: HCORENUM; td: ULONG;
      rEvents: PULONG; cMax: ULONG;
      out pcEvents: ULONG); safecall;
    procedure GetEventProps(ev: ULONG; pClass: PULONG;
      szEvent: PWideChar; cchEvent: ULONG; pchEvent, pdwEventFlags,
      ptkEventType, pmdAddOn, pmdFire, rmdOtherMethod: PULONG;
      cMax: ULONG; pcOtherMethod: PULONG); safecall;
    procedure EnumMethodSemantics(var phEnum: HCORENUM; mb: ULONG;
      rEventProp: PULONG; cMax: ULONG;
      out pcEventProp: ULONG); stdcall;
    procedure GetMethodSemantics(mb, tkEventProp: ULONG;
      out pdwSemanticsFlags: DWORD); safecall;
    procedure GetClassLayout(td: ULONG; out pdwPackSize: DWORD;
      rFieldOffset: PCOR_FIELD_OFFSET; cMax: ULONG;
      out pcFieldOffset: ULONG; out pulClassSize: ULONG); safecall;
    procedure GetFieldMarshal(tk: ULONG; out ppvNativeType: PCCOR_SIGNATURE;
      out pcbNativeType: ULONG); safecall;
    procedure GetRVA(tk: ULONG; var pulCodeRVA: ULONG;
      var pdwImplFlags: DWORD); safecall;
    procedure GetPermissionSetProps(pm: ULONG; out pdwAction: ULONG;
      out ppvPermission: Pointer; out pcbPermission: ULONG); safecall;
    procedure GetSigFromToken(mdSig: ULONG; out ppvSig: PCCOR_SIGNATURE;
      out pcbSig: ULONG); safecall;
    procedure GetModuleRefProps(mr: ULONG; szName: PWideChar;
      cchName: ULONG; out pchName: ULONG); safecall;
    procedure EnumModuleRefs(var phEnum: HCORENUM;
      rModuleRefs: PULONG; cmax: ULONG;
      out pcModuleRefs: ULONG); safecall;
    procedure GetTypeSpecFromToken(typespec: ULONG;
      out ppvSig: PCCOR_SIGNATURE; out pcbSig: ULONG); safecall;
    procedure GetNameFromToken(tk: ULONG;
      out pszUtf8NamePtr: PChar); safecall;
    procedure EnumUnresolvedMethods(var phEnum: HCORENUM;
      rMethods: PULONG; cMax: ULONG; out pcTokens: ULONG); safecall;
    procedure GetUserString(stk: ULONG; szString: PWideChar;
      cchString: ULONG; out pchString: ULONG); safecall;
    procedure GetPinvokeMap(tk: ULONG; out pdwMappingFlags: DWORD;
      szImportName: PWideChar; cchImportName: ULONG;
      out pchImportName: ULONG; out pmrImportDLL: ULONG); safecall;
    procedure EnumSignatures(var phEnum: HCORENUM;
      rSignatures: PULONG; cmax: ULONG;
      out pcSignatures: ULONG); safecall;
    procedure EnumTypeSpecs(var phEnum: HCORENUM;
      rTypeSpecs: PULONG; cmax: ULONG;
      out pcTypeSpecs: ULONG); safecall;
    procedure EnumUserStrings(var phEnum: HCORENUM;
      rStrings: PULONG; cmax: ULONG;
      out pcStrings: ULONG); safecall;
    procedure GetParamForMethodIndex(md: ULONG; ulParamSeq: ULONG;
      var ppd: ULONG); safecall;
    procedure EnumCustomAttributes(var phEnum: HCORENUM; tk: ULONG;
      tkType: ULONG; rCustomAttributes: PULONG;
      cMax: ULONG; pcTokens: PULONG); safecall;
    procedure GetCustomAttributeProps(cv: ULONG;
      ptkObj, ptkType: PULONG; ppBlob: PPointer;
      pcbSize: PULONG); safecall;
    procedure FindTypeRef(tkResolutionScope: ULONG; szName: PWideChar;
      out ptr: ULONG); safecall;
    procedure GetMemberProps(mb: ULONG; var pClass: ULONG;
      szMember: PWideChar; cchMember: ULONG; var pchMember: ULONG;
      var pdwAttr: DWORD; ppvSigBlob: PPCCOR_SIGNATURE;
      pcbSigBlob, pulCodeRVA, pdwImplFlags, pdwCPlusTypeFlag: PULONG;
      ppValue: PPointer; pcchValue: PULONG); safecall;
    procedure GetFieldProps(mb: ULONG; var pClass: ULONG;
      szField: PWideChar; cchField: ULONG; var pchField: ULONG;
      var pdwAttr: DWORD; ppvSigBlob: PPCCOR_SIGNATURE;
      pcbSigBlob: PULONG; pdwCPlusTypeFlag: PDWORD;
      ppValue: PPointer; pcchValue: PULONG); safecall;
    procedure GetPropertyProps(prop: ULONG; pClass: PULONG;
      szProperty: PWideChar; cchProperty: ULONG; pchProperty: PULONG;
      pdwPropFlags: PDWORD; ppvSig: PPCCOR_SIGNATURE;
      pbSig: PULONG; pdwCPlusTypeFlag: PDWORD;
      ppDefaultValue: PPointer; pcchDefaultValue, pmdSetter, pmdGetter,
      rmdOtherMethod: PULONG; cMax: ULONG; pcOtherMethod: PULONG); safecall;
    procedure GetParamProps(tk: ULONG; pmd, pulSequence: PULONG;
      szName: PWideChar; cchName: ULONG; pchName: PULONG;
      pdwAttr, pdwCPlusTypeFlag: PDWORD; ppValue: PPointer;
      pcchValue: PULONG); safecall;
    procedure GetCustomAttributeByName(tkObj: ULONG; szName: PWideChar;
      out ppData: Pointer; out pcbData: ULONG); safecall;
    function IsValidToken(tk: ULONG): Boolean; stdcall;
    procedure GetNestedClassProps(tdNestedClass: ULONG;
      out ptdEnclosingClass: ULONG); safecall;
    procedure GetNativeCallConvFromSig(pvSig: Pointer; cbSig: ULONG;
      out pCallConv: ULONG); safecall;
    procedure IsGlobal(pd: ULONG; out pbGlobal: ULONG); safecall;
  end;

implementation

end.
